#include <ansi_c.h>
#include <visa.h>
#include <cvirte.h>     
#include <userint.h>
#include "rssmf.h"
#include "RSSMF_AM_Example.h"

/* Error check macro for driver functions */

#define CHECKERR( fCal ) \
    { \
        error = (fCal);\
        rssmf_error_message (io, error, error_message);\
        if (error < VI_SUCCESS) {\
            sprintf (error_buffer, "Primary Error: 0x%08X, %s\n", error, error_message);\
            MessagePopup ("Error", error_buffer); \
            rssmf_error_query (io, &error, error_message);\
            sprintf (error_buffer, "Secondary Error: 0x%08X, %s\n", error, error_message);\
            SetCtrlAttribute (panelHandle, PANEL_APPLY, ATTR_DIMMED, 0);\
            SetCtrlAttribute (panelHandle, PANEL_Exit, ATTR_DIMMED, 0);\
            SetWaitCursor (0); \
            MessagePopup ("Error", error_buffer); \
            rssmf_close(io); \
            io = NULL;\
            return -1; \
        } \
    }
    
/* Globals */
static int lfg1Panel, panelHandle, lfg2panel;
static int noisepanel;

ViBoolean grfState;
ViReal64  grfLevel, grfFrequency, gbandwidth,
          glfGen1Freq, grise1, gfall1, ghigh1, gperiod1, gamDepth, glfGen2Freq, grise2, 
          gfall2, ghigh2, gperiod2, gpulsePeriod1, gpulseWidth1, gpulseDutyCycle1, 
          gpulsePeriod2, gpulseWidth2, gpulseDutyCycle2, gtrianglePeriod1, gtriangleRise1,
          gtrianglePeriod2, gtriangleRise2;
ViInt32   gamSource, gnoiseDistribution, gshape1, gshape2, gnoiseBwidLim, gamState;
ViStatus  error;
ViSession io = NULL;
ViChar    error_message[256];
ViChar    error_buffer[256];

/* Local Functions */
int initialize (void);

int main (int argc, char *argv[])
{
    if (InitCVIRTE (0, argv, 0) == 0)
        return -1;  /* out of memory */
    if ((lfg1Panel = LoadPanel (0, "RSSMF_AM_Example.uir", LFG1_PANEL)) < 0)
        return -1;
    if ((panelHandle = LoadPanel (0, "RSSMF_AM_Example.uir", PANEL)) < 0)
        return -1;
    if ((lfg2panel = LoadPanel (0, "RSSMF_AM_Example.uir", LFG2PANEL)) < 0)
        return -1;
    if ((noisepanel = LoadPanel (0, "RSSMF_AM_Example.uir", NOISEPANEL)) < 0)
        return -1;
    
    /* Default Values */
    grfState           = VI_FALSE;
    grfLevel           = -30.0;
    grfFrequency       = 1E9;
    gbandwidth         = 100e3;
    glfGen1Freq        = 1e3;
    glfGen2Freq        = 1e3;
    grise1              = 1e-6; 
    gfall1              = 1e-6;
    ghigh1              = 1e-6;
    gperiod1               = 1e-3;
    grise2              = 1e-6; 
    gfall2              = 1e-6;
    ghigh2              = 1e-6;
    gperiod2               = 1e-3;
    gpulsePeriod1       = 1.0e-3;
    gpulseWidth1        = 0.5e-3;
    gpulseDutyCycle1    = 50.0;
    gtrianglePeriod1    = 1.0e-3;
    gtriangleRise1      = 0.5e-3;
    gpulsePeriod2       = 1.0e-3;
    gpulseWidth2        = 0.5e-3;
    gpulseDutyCycle2    = 50.0;
    gtrianglePeriod2    = 1.0e-3;
    gtriangleRise2      = 0.5e-3;
    gamSource          = 0;
    gnoiseDistribution = 0;
    gshape1             = 0;
    gshape2            = 0;
    gnoiseBwidLim      = 0;
    gamState           = 0;
    gamDepth           = 30.0;
    
    DisplayPanel (panelHandle);
    RunUserInterface ();
    DiscardPanel (panelHandle);
    DiscardPanel (noisepanel);
    DiscardPanel (lfg2panel);
    DiscardPanel (lfg1Panel);
    
    return 0;
}

/*===========================================================================*/
/* Function: Apply Settings                                                  */
/* Purpose:  This is a callback function of Apply button. The values are     */
/*           send to the instrument                                          */
/*===========================================================================*/
int CVICALLBACK apllySettings (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            /* Initialize driver */
            if (io == VI_NULL)
            {
                if (initialize() < VI_SUCCESS) break;
            }

            SetCtrlAttribute (panelHandle, PANEL_APPLY, ATTR_DIMMED, 1);
            SetCtrlAttribute (panelHandle, PANEL_Exit, ATTR_DIMMED, 1);
            ProcessDrawEvents ();

            SetWaitCursor(1);

            /* Get values from controls */
            GetCtrlVal (panelHandle, PANEL_RF_FREQ, &grfFrequency);
            GetCtrlVal (panelHandle, PANEL_RF_LEVEL, &grfLevel);
            GetCtrlVal (panelHandle, PANEL_RF_STATE, &grfState);
            GetCtrlVal (panelHandle, PANEL_AM_STATE, &gamState);
            GetCtrlVal (panelHandle, PANEL_AM_DEPTH, &gamDepth);            
            GetCtrlVal (panelHandle, PANEL_AM_SOURCE, &gamSource);
            
            /* Configure RF output part */
            CHECKERR (rssmf_confRFFreq (io, grfFrequency, 0.0, 1.0, VI_FALSE, 1.0e6));
            CHECKERR (rssmf_confRFLevel (io, grfLevel, 0.0, 30.0, RSSMF_POWER_RESOLUTION_R1,
                                         VI_FALSE, 1.0, RSSMF_POWER_LEVEL_RCL_EXCLUDE));

            /* Configure selected AM source */
            
            switch (gamSource)
            {
                case RSSMF_LFOUTPUT_SOURCE_NOISE:
                    CHECKERR (rssmf_confNoise (io, gbandwidth, gnoiseDistribution));
                    break;
                case RSSMF_LFOUTPUT_SOURCE_LF1:
                    CHECKERR (rssmf_SetLFGenFrequency (io, 1, glfGen1Freq));
                    CHECKERR (rssmf_SetLFGenShape (io, 1, gshape1));
                    switch (gshape1)
                    {
                        case RSSMF_LFOUTPUT_SHAPE_SQUARE:
                            CHECKERR (rssmf_SetLFGenShapePulse (io, 1,
                                                                RSSMF_LFOUTPUT_SHAPE_PULSE_DUTY,
                                                                gpulseDutyCycle1));
                            CHECKERR (rssmf_SetLFGenShapePulse (io, 1,
                                                                RSSMF_LFOUTPUT_SHAPE_PULSE_PERIOD,
                                                                gpulsePeriod1));
                            CHECKERR (rssmf_SetLFGenShapePulse (io, 1,
                                                                RSSMF_LFOUTPUT_SHAPE_PULSE_WIDTH,
                                                                gpulseWidth1));
                            break;
                        case RSSMF_LFOUTPUT_SHAPE_TRIANGLE:
                            CHECKERR (rssmf_SetLFGenShapeTriangle (io, 1,
                                                         RSSMF_LFOUTPUT_SHAPE_TRIANGLE_PERIOD,
                                                         gtrianglePeriod1));
                            CHECKERR (rssmf_SetLFGenShapeTriangle (io, 1,
                                                         RSSMF_LFOUTPUT_SHAPE_TRIANGLE_RISE,
                                                         gtriangleRise1));
                            
                            break;
                        case RSSMF_LFOUTPUT_SHAPE_TRAPEZE:
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 1, RSSMF_LFOUTPUT_SHAPE_TRAPEZE_FALL,
                                                       gfall1));
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 1, RSSMF_LFOUTPUT_SHAPE_TRAPEZE_HIGH,
                                                       ghigh1));
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 1,
                                                       RSSMF_LFOUTPUT_SHAPE_TRAPEZE_PERIOD,
                                                       gperiod1));
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 1, RSSMF_LFOUTPUT_SHAPE_TRAPEZE_RISE,
                                                       grise1));
                            
                            
                            
                            break;

                    }
                    break;
                case RSSMF_LFOUTPUT_SOURCE_LF2:
                    CHECKERR (rssmf_SetLFGenFrequency (io, 2, glfGen2Freq));
                    CHECKERR (rssmf_SetLFGenShape (io, 2, gshape2));
                    switch (gshape2)
                    {
                        case RSSMF_LFOUTPUT_SHAPE_SQUARE:
                            CHECKERR (rssmf_SetLFGenShapePulse (io, 2,
                                                                RSSMF_LFOUTPUT_SHAPE_PULSE_DUTY,
                                                                gpulseDutyCycle2));
                            CHECKERR (rssmf_SetLFGenShapePulse (io, 2,
                                                                RSSMF_LFOUTPUT_SHAPE_PULSE_PERIOD,
                                                                gpulsePeriod2));
                            CHECKERR (rssmf_SetLFGenShapePulse (io, 2,
                                                                RSSMF_LFOUTPUT_SHAPE_PULSE_WIDTH,
                                                                gpulseWidth2));
                            break;
                        case RSSMF_LFOUTPUT_SHAPE_TRIANGLE:
                            CHECKERR (rssmf_SetLFGenShapeTriangle (io, 2,
                                                         RSSMF_LFOUTPUT_SHAPE_TRIANGLE_PERIOD,
                                                         gtrianglePeriod2));
                            CHECKERR (rssmf_SetLFGenShapeTriangle (io, 2,
                                                         RSSMF_LFOUTPUT_SHAPE_TRIANGLE_RISE,
                                                         gtriangleRise2));
                            
                            break;
                        case RSSMF_LFOUTPUT_SHAPE_TRAPEZE:
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 2, RSSMF_LFOUTPUT_SHAPE_TRAPEZE_FALL,
                                                       gfall2));
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 2, RSSMF_LFOUTPUT_SHAPE_TRAPEZE_HIGH,
                                                       ghigh2));
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 2,
                                                       RSSMF_LFOUTPUT_SHAPE_TRAPEZE_PERIOD,
                                                       gperiod2));
                           CHECKERR (rssmf_SetLFGenShapeTrapeze (io, 2, RSSMF_LFOUTPUT_SHAPE_TRAPEZE_RISE,
                                                       grise2));
                            
                            
                            
                            break;

                    }
                    break;
				
					
					
            }
			
             /* switch LF Output mode  */
			 CHECKERR (rssmf_SetLFOutputMonitoring (io,gamState));       
			
            /* According to selected source configure source parameters. */
            /* Configure common AM settings */
            CHECKERR (rssmf_configAM (io, 1, gamState, gamSource, gamDepth, VI_FALSE, 1.0,
                                      50.0));

            /* Turn On/Off RF output at the end of sequence */
            CHECKERR (rssmf_SetOutputState(io, grfState));

            SetCtrlAttribute (panelHandle, PANEL_APPLY, ATTR_DIMMED, 0);
            SetCtrlAttribute (panelHandle, PANEL_Exit, ATTR_DIMMED, 0);

            SetWaitCursor(0);
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: OK - LF Gen 1 Settings                                          */
/* Purpose:  Stores LF Gen 1 values into variables                           */
/*===========================================================================*/
int CVICALLBACK Lfgen1Ok (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_FREQ, &glfGen1Freq);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_SHAPE, &gshape1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_PERIOD, &gperiod1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_HIGH, &ghigh1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_RISE, &grise1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_FALL, &gfall1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEDUTY, &gpulseDutyCycle1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEWIDTH, &gpulseWidth1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEPERIOD, &gpulsePeriod1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLERISE, &gtriangleRise1);
            GetCtrlVal (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLEPERIOD,
                        &gtrianglePeriod1);
            HidePanel (lfg1Panel);
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: OK - LF Gen 2 Settings                                          */
/* Purpose:  Stores LF Gen 2 values into variables                           */
/*===========================================================================*/
int CVICALLBACK Lfgen2Ok (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_FREQ, &glfGen2Freq); 
            GetCtrlIndex (lfg2panel, LFG2PANEL_LFGEN2_SHAPE, &gshape2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_RISE, &grise2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_FALL, &gfall2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_HIGH, &ghigh2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_PERIOD, &gperiod2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_PULSEDUTY, &gpulseDutyCycle2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_PULSEWIDTH, &gpulseWidth2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_PULSEPERIOD, &gpulsePeriod2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLERISE, &gtriangleRise2);
            GetCtrlVal (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLEPERIOD,
                        &gtrianglePeriod2);

            HidePanel (lfg2panel);
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: OK - Noise Settings                                             */
/* Purpose:  Stores Noise values into variables                              */
/*===========================================================================*/
int CVICALLBACK NoiseOk (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            GetCtrlVal (noisepanel, NOISEPANEL_NOISE_DISTRIBUTION, &gnoiseDistribution); 
            GetCtrlVal (noisepanel, NOISEPANEL_NOISE_BWID, &gbandwidth);
            HidePanel (noisepanel);

            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Source Changed                                                  */
/* Purpose:  This is a callback function of chaging FM source.               */
/*===========================================================================*/
int CVICALLBACK SourceChanged (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            
            GetCtrlVal (panel, control, &gamSource);

            switch (gamSource)
            {
                case 0: // LF Gen 1
                    SetCtrlAttribute (panel, PANEL_LFGEN1_BUTTON, ATTR_DIMMED, 0);
                    SetCtrlAttribute (panel, PANEL_LFGEN2_BUTTON, ATTR_DIMMED, 1);
                    SetCtrlAttribute (panel, PANEL_NOISE_BUTTON, ATTR_DIMMED, 1);
                    break;
                case 1: // LF Gen 2
                    SetCtrlAttribute (panel, PANEL_LFGEN1_BUTTON, ATTR_DIMMED, 1);
                    SetCtrlAttribute (panel, PANEL_LFGEN2_BUTTON, ATTR_DIMMED, 0);
                    SetCtrlAttribute (panel, PANEL_NOISE_BUTTON, ATTR_DIMMED, 1);
                    break;
                case 4:
                    SetCtrlAttribute (panel, PANEL_LFGEN1_BUTTON, ATTR_DIMMED, 1);
                    SetCtrlAttribute (panel, PANEL_LFGEN2_BUTTON, ATTR_DIMMED, 1);
                    SetCtrlAttribute (panel, PANEL_NOISE_BUTTON, ATTR_DIMMED, 0);
                    break;
            }
            
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Show LF Gen 2                                                   */
/* Purpose:  This is a callback function of LF Gen 2 Settings button.        */
/*===========================================================================*/
int CVICALLBACK Lfgen2Button (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            DisplayPanel (lfg2panel);

            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Show Noise                                                      */
/* Purpose:  This is a callback function of Noise Settings button. Shows     */
/*           noise settings panel.                                           */
/*===========================================================================*/
int CVICALLBACK NoiseButton (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            DisplayPanel (noisepanel);
            
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Show LF Gen 1                                                   */
/* Purpose:  This is a callback function of LF Gen 1 Settings button.        */
/*===========================================================================*/
int CVICALLBACK Lfgen1Button (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            DisplayPanel (lfg1Panel);
            break;
    }
    return 0;
}

/*===========================================================================*/
/* Function: Panel Help                                                      */
/* Purpose:  This is a callback function of the menu bar. It displays a help */
/*           window describing panel being used.                             */
/*===========================================================================*/
void CVICALLBACK panelHelp (int menuBar, int menuItem, void *callbackData,
        int panel)
{
    if (panel == panelHandle)
        MessagePopup ("Help", "This is a simple demo program using\n"
                              "the Rohde&Schwarz SMA Signal Generator\n"
                              "instrument driver provided in the package.\n");
}

/*===========================================================================*/
/* Function: Exit                                                            */
/* Purpose:  This is a callback function of Exit button. It closes the       */
/*           session and exits the example.                                  */
/*===========================================================================*/
int CVICALLBACK exitApp (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            if (io) rssmf_close (io);
            QuitUserInterface (0);
            break;
    }
    return 0;
}

/*===========================================================================*/ 
/* Local Functions Definitions                                               */
/*===========================================================================*/

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function initializes the instrument, performs ID Query     */
/*           and Reset                                                       */
/*===========================================================================*/
int initialize (void)
{
    ViChar      instr_desc[256];
    ViBoolean   id;
    ViBoolean   rst;


    SetWaitCursor(0);
    GetCtrlVal (panelHandle, PANEL_INSTR_DESC, instr_desc);
    GetCtrlVal (panelHandle, PANEL_IDQUERY, &id);
    GetCtrlVal (panelHandle, PANEL_RESET, &rst);
    SetWaitCursor(1);
    if ((error = rssmf_init (instr_desc, id, rst, &io)) < 0 )
    {
        rssmf_error_message(VI_NULL, error, error_message);
        sprintf (error_buffer, "Initialization Error:\n\n%s\n\nCheck your "
                "connections and make sure you have the right instrument descriptor.",
                 error_message);
        MessagePopup ("ERROR!", error_buffer);
        SetWaitCursor(0);
        return(-1);   
    }

    viSetAttribute (io, VI_ATTR_TMO_VALUE, 10000);

    SetWaitCursor(0);
    return 0;
}

int CVICALLBACK LFGen1ShapeChanged (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            GetCtrlIndex (lfg1Panel, LFG1_PANEL_LFGEN1_SHAPE, &gshape1);
            switch (gshape1)
            {
                case RSSMF_LFOUTPUT_SHAPE_SINE:
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_RISE, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_FALL, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_HIGH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEWIDTH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEDUTY, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLERISE, ATTR_VISIBLE, 0);
                    break;
                case RSSMF_LFOUTPUT_SHAPE_SQUARE:
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_RISE, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_FALL, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_HIGH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEPERIOD, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEWIDTH, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEDUTY, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLERISE, ATTR_VISIBLE, 0);
                    break;
                case RSSMF_LFOUTPUT_SHAPE_TRIANGLE:
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_RISE, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_FALL, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_HIGH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEWIDTH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEDUTY, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLEPERIOD, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLERISE, ATTR_VISIBLE, 1);
                    break;
                case RSSMF_LFOUTPUT_SHAPE_TRAPEZE:
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_RISE, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_FALL, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_HIGH, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PERIOD, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEWIDTH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_PULSEDUTY, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg1Panel, LFG1_PANEL_LFGEN1_TRIANGLERISE, ATTR_VISIBLE, 0);
                    break;

            }
            break;
    }
    return 0;
}

int CVICALLBACK LFGen2ShapeChanged (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event)
    {
        case EVENT_COMMIT:
            GetCtrlIndex (lfg2panel, LFG2PANEL_LFGEN2_SHAPE, &gshape1);
            switch (gshape1)
            {
                case RSSMF_LFOUTPUT_SHAPE_SINE:
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_RISE, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_FALL, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_HIGH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEWIDTH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEDUTY, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLERISE, ATTR_VISIBLE, 0);
                    break;
                case RSSMF_LFOUTPUT_SHAPE_SQUARE:
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_RISE, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_FALL, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_HIGH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEPERIOD, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEWIDTH, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEDUTY, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLERISE, ATTR_VISIBLE, 0);
                    break;
                case RSSMF_LFOUTPUT_SHAPE_TRIANGLE:
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_RISE, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_FALL, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_HIGH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEWIDTH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEDUTY, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLEPERIOD, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLERISE, ATTR_VISIBLE, 1);
                    break;
                case RSSMF_LFOUTPUT_SHAPE_TRAPEZE:
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_RISE, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_FALL, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_HIGH, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PERIOD, ATTR_VISIBLE, 1);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEWIDTH, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_PULSEDUTY, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLEPERIOD, ATTR_VISIBLE, 0);
                    SetCtrlAttribute (lfg2panel, LFG2PANEL_LFGEN2_TRIANGLERISE, ATTR_VISIBLE, 0);
                    break;

            }
            break;
    }
    return 0;
}
